from modern_di_faststream.main import FromDI, faststream_message_provider, fetch_di_container, setup_di


__all__ = [
    "FromDI",
    "faststream_message_provider",
    "fetch_di_container",
    "setup_di",
]
